@@ -3,7 +3,7 @@ import logging
 import socket
 from msmart.security import security, MSGTYPE_HANDSHAKE_REQUEST, MSGTYPE_ENCRYPTED_REQUEST
 
-VERSION = '0.1.28'
+VERSION = '0.1.29'
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -29,8 +29,9 @@ class lan:
             try:
                 self._socket.connect((self.device_ip, self.device_port))
             except Exception as error:
+                _LOGGER.error("Connect Error: {}:{} {}".format(
+                    self.device_ip, self.device_port, error))
                 self._disconnect()
-                raise error
 
     def _disconnect(self):
         if self._socket:
@@ -43,7 +44,9 @@ class lan:
 
         try:
             if self._socket is None:
-                raise socket.error
+                _LOGGER.error("Sokcet is None: {}:{}".format(
+                    self.device_ip, self.device_port))
+                return bytearray(0)
             # Send data
             _LOGGER.debug("Sending to {}:{} {}".format(
                 self.device_ip, self.device_port, message.hex()))
@@ -51,13 +54,13 @@ class lan:
 
             # Received data
             response = self._socket.recv(1024)
-        except socket.error:
-            _LOGGER.info("Couldn't connect with Device {}:{}".format(
-                self.device_ip, self.device_port))
+        except socket.error as error:
+            _LOGGER.error("Couldn't connect with Device {}:{} {}".format(
+                self.device_ip, self.device_port, error))
             self._disconnect()
             return bytearray(0)
         except socket.timeout:
-            _LOGGER.info("Connect the Device {}:{} TimeOut for 8s. don't care about a small amount of this. if many maybe not support".format(
+            _LOGGER.error("Connect the Device {}:{} TimeOut for 8s. don't care about a small amount of this. if many maybe not support".format(
                 self.device_ip, self.device_port))
             self._disconnect()
             return bytearray(0)
@@ -74,12 +77,12 @@ class lan:
         response = self.request(request)[8:72]
         try:
             tcp_key = self.security.tcp_key(response, self._key)
-            _LOGGER.debug('Got TCP key for {}:{} {}'.format(
+            _LOGGER.info('Got TCP key for {}:{} {}'.format(
                 self.device_ip, self.device_port, tcp_key.hex()))
         except Exception as error:
             self._disconnect()
             raise error
-    
+
     def _authenticate(self):
         if not self._token or not self._key:
             raise Exception('missing token key pair')
@@ -99,7 +102,20 @@ class lan:
         return packets
 
     def appliance_transparent_send(self, data):
-        response = self.request(data)
-        if len(response) > 40 + 16:
-            return [self.security.aes_decrypt(response[40:-16])]
-        return [response]
+        responses = self.request(data)
+        _LOGGER.debug("Got responses len: {}".format(len(responses)))
+        if responses == bytearray(0):
+            return responses
+        packets = []
+        if responses[:2].hex() == "5a5a":
+            # maybe multiple response
+            for response in responses.split(bytearray.fromhex('5a5a')):
+                # 5a5a been removed, so (40-2)+16
+                if len(response) > 38 + 16:
+                    packets.append(self.security.aes_decrypt(response[38:-16]))
+        elif responses[0] == 0xaa:
+            for response in responses.split(bytearray.fromhex('aa')):
+                packets.append(bytearray.fromhex('aa') + response)
+        else:
+            _LOGGER.error("Unknown responses {}".format(responses.hex()))
+        return packets
